@@ -81,10 +81,10 @@ class Client():
       return self.put("passes/" + str(pass_id) + "/push", options)
   
     def redeem_pass(self, pass_id):
-      return self.post("passes/" + str(pass_id) + "/redeem")
+      return self.post("passes/" + str(pass_id) + "/redeem", {})
 
     def archive_pass(self, pass_id):
-      return self.post("passes/" + str(pass_id) + "/archive")
+      return self.post("passes/" + str(pass_id) + "/archive", {})
     
     def distribute_campaign(self, campaign_id):
       return self.post("campaigns/" + str(campaign_id) + "/distribute")
